@@ -37,7 +37,6 @@
 #define BOOKMARKS_PATH "xfce4/appfinder/bookmarks"
 
 
-
 static void               xfce_appfinder_model_tree_model_init        (GtkTreeModelIface        *iface);
 static void               xfce_appfinder_model_get_property           (GObject                  *object,
                                                                        guint                     prop_id,
@@ -101,6 +100,8 @@ static void               xfce_appfinder_model_bookmarks_monitor_stop (XfceAppfi
 static void               xfce_appfinder_model_bookmarks_monitor      (XfceAppfinderModel       *model,
                                                                        const gchar              *path);
 
+static gboolean           xfce_appfinder_model_fuzzy_match            (const gchar              *source,
+                                                                       const gchar              *token);
 
 
 struct _XfceAppfinderModelClass
@@ -230,8 +231,8 @@ xfce_appfinder_model_init (XfceAppfinderModel *model)
   model->items_hash = g_hash_table_new (g_str_hash, g_str_equal);
   model->bookmarks_hash = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
   model->icon_size = XFCE_APPFINDER_ICON_SIZE_DEFAULT_ITEM;
-  model->command_icon = xfce_appfinder_model_load_pixbuf (GTK_STOCK_EXECUTE, model->icon_size);
-  model->command_icon_large = xfce_appfinder_model_load_pixbuf (GTK_STOCK_EXECUTE, XFCE_APPFINDER_ICON_SIZE_48);
+  model->command_icon = xfce_appfinder_model_load_pixbuf (XFCE_APPFINDER_STOCK_EXECUTE, model->icon_size);
+  model->command_icon_large = xfce_appfinder_model_load_pixbuf (XFCE_APPFINDER_STOCK_EXECUTE, XFCE_APPFINDER_ICON_SIZE_48);
   model->command_category = xfce_appfinder_model_get_command_category ();
   model->collect_cancelled = g_cancellable_new ();
 
@@ -737,8 +738,6 @@ xfce_appfinder_model_collect_idle (gpointer user_data)
 
   APPFINDER_DEBUG ("insert idle start");
 
-  GDK_THREADS_ENTER ();
-
   /* move the collected items "online" */
   model->items = model->collect_items;
   model->collect_items = NULL;
@@ -793,8 +792,6 @@ xfce_appfinder_model_collect_idle (gpointer user_data)
       g_slist_free (tmp);
     }
 
-  GDK_THREADS_LEAVE ();
-
   APPFINDER_DEBUG ("insert idle end");
 
   return FALSE;
@@ -1897,7 +1894,7 @@ xfce_appfinder_model_collect_thread (gpointer user_data)
       model->collect_items = g_slist_sort (model->collect_items, xfce_appfinder_model_item_compare);
       model->collect_categories = g_slist_sort (model->collect_categories, xfce_appfinder_model_category_compare);
 
-      model->collect_idle_id = g_idle_add_full (G_PRIORITY_LOW, xfce_appfinder_model_collect_idle,
+      model->collect_idle_id = gdk_threads_add_idle_full (G_PRIORITY_LOW, xfce_appfinder_model_collect_idle,
                                                 model, xfce_appfinder_model_collect_idle_destroy);
     }
 
@@ -2020,7 +2017,7 @@ xfce_appfinder_model_get_visible (XfceAppfinderModel        *model,
 
       if (string != NULL
           && item->key != NULL)
-        return strstr (item->key, string) != NULL;
+        return xfce_appfinder_model_fuzzy_match (item->key, string);
     }
   else /* command item */
     {
@@ -2030,7 +2027,7 @@ xfce_appfinder_model_get_visible (XfceAppfinderModel        *model,
         return FALSE;
 
       if (string != NULL)
-        return strstr (item->command, string) != NULL;
+        return xfce_appfinder_model_fuzzy_match (item->command, string);
     }
 
   return TRUE;
@@ -2059,7 +2056,7 @@ xfce_appfinder_model_get_visible_command (XfceAppfinderModel *model,
     }
 
   if (item->command != NULL && string != NULL)
-    return strncmp (item->command, string, strlen (string)) == 0;
+    return xfce_appfinder_model_fuzzy_match (item->command, string);
 
   return FALSE;
 }
@@ -2342,11 +2339,11 @@ xfce_appfinder_model_icon_theme_changed (XfceAppfinderModel *model)
   /* reload the command icons */
   if (model->command_icon != NULL)
     g_object_unref (G_OBJECT (model->command_icon));
-  model->command_icon = xfce_appfinder_model_load_pixbuf (GTK_STOCK_EXECUTE, model->icon_size);
+  model->command_icon = xfce_appfinder_model_load_pixbuf (XFCE_APPFINDER_STOCK_EXECUTE, model->icon_size);
 
   if (model->command_icon_large != NULL)
     g_object_unref (G_OBJECT (model->command_icon_large));
-  model->command_icon_large = xfce_appfinder_model_load_pixbuf (GTK_STOCK_EXECUTE, XFCE_APPFINDER_ICON_SIZE_48);
+  model->command_icon_large = xfce_appfinder_model_load_pixbuf (XFCE_APPFINDER_STOCK_EXECUTE, XFCE_APPFINDER_ICON_SIZE_48);
 
   /* update the model items */
   for (li = model->items, idx = 0; li != NULL; li = li->next, idx++)
@@ -2421,7 +2418,7 @@ xfce_appfinder_model_bookmark_toggle (XfceAppfinderModel  *model,
   static gsize  old_len = 0;
   GString      *contents;
   gchar        *filename;
-  gboolean      succeed;
+  gboolean      succeed = FALSE;
   GtkTreePath  *path;
   gint          idx;
   GtkTreeIter   iter;
@@ -2517,7 +2514,7 @@ xfce_appfinder_model_get_command_category (void)
     {
       category = g_object_new (GARCON_TYPE_MENU_DIRECTORY,
                                "name", _("Commands History"),
-                               "icon-name", GTK_STOCK_EXECUTE,
+                               "icon-name", XFCE_APPFINDER_STOCK_EXECUTE,
                                NULL);
       appfinder_refcount_debug_add (G_OBJECT (category), "commands");
       g_object_add_weak_pointer (G_OBJECT (category), (gpointer) &category);
@@ -2549,3 +2546,53 @@ xfce_appfinder_model_get_bookmarks_category (void)
 
   return category;
 }
+
+
+
+gboolean
+xfce_appfinder_model_fuzzy_match (const gchar *source,
+                                  const gchar *token)
+{
+    const guint token_size = strlen (token);
+    const guint cmd_part_size = token_size + 1;
+    guint index;
+    gboolean match = FALSE;
+    gboolean contain_uppercase = FALSE;
+
+    // length is chosen because of ".*<part1> *.*(?i)<part2>.*" pattern format
+    // "(?i)" is optional part
+    gchar pattern [token_size + 14];
+    gchar cmd_part [cmd_part_size];
+    gchar *param_part;
+
+    if (strcmp (token,"") == 0)
+        return TRUE;
+
+    for (index=1; !match && (index <= token_size); index++)
+      {
+        memset (cmd_part, 0, cmd_part_size);
+        strncpy (cmd_part, token, index);
+        cmd_part [index + 1] = '\0';
+
+        contain_uppercase = FALSE;
+        param_part = (gchar*) token + index;
+
+        while (!contain_uppercase && (*param_part != '\0'))
+          {
+            contain_uppercase = g_ascii_isupper (*param_part);
+            param_part++;
+          }
+
+        memset (pattern, 0, sizeof (pattern));
+        g_sprintf (pattern, ".*%s *.*%s%s.*", cmd_part,
+                   (contain_uppercase) ? "(?-i)" : "(?i)",
+                   token + index);
+        match = g_regex_match_simple (pattern, source, 0, 0);
+        if (match)
+          {
+            APPFINDER_DEBUG ("Fuzzy match: regexp=%s ; source=%s", pattern, source);
+          }
+      }
+
+    return match;
+}
